==> picomet-0.0.34.tar.gz: picomet-0.0.34/README.md <==
# Picomet

![PyPI - Python Versions](https://img.shields.io/pypi/pyversions/picomet)
![PyPI - Django Versions](https://img.shields.io/pypi/djversions/picomet)
[![PyPI - Version](https://img.shields.io/pypi/v/picomet)](https://pypi.org/project/picomet)
![PyPI - Downloads](https://img.shields.io/pypi/dw/picomet)
![GitHub](https://img.shields.io/github/license/picomet/picomet)
[![Discord](https://img.shields.io/badge/Discord-5865f2.svg?logo=discord&logoColor=white)](https://discord.gg/4byApQZg8X)

> **Tip**: Picomet isn't stable at this moment. Stability is expected with the 1.0.0 release. Remember to run `pip install --upgrade picomet` from time to time, to get the latest features and bug fixes.

## Introduction

Picomet allows you to build Single Page Applications (SPAs) with Server-Side Rendering (SSR) capabilities, seamlessly integrated with Django. What sets this framework apart is its ability to render Alpinejs syntax on the server and to update any specific part of a page by partially rending it on the server.

## Features

-   🏠 Single page app
-   🔎 Partial rendering
-   🏯 Nested layout
-   ☎️ Server action
-   ⚡ Hot module reload
-   🌲 Alpine.js support
-   🖌️ Tailwind support
-   ✨ Copier starter

## Getting Started

Go to https://picomet.readthedocs.io for getting started

## Contribution Guideline

We welcome contributions from the community to enhance and improve the framework. If you'd like to contribute, please read [CONTRIBUTING.md](CONTRIBUTING.md).

## License

Picomet is licensed under the **MIT License**. Feel free to use it in your projects and make it even better!

## Support

If you have any questions, issues, or feature requests, please open an issue or create a discussion on GitHub. We appreciate your feedback!

Happy coding! 🚀

==> picomet-0.0.36.tar.gz: picomet-0.0.36/README.md <==
# Picomet

![PyPI - Python Versions](https://img.shields.io/pypi/pyversions/picomet)
![PyPI - Django Versions](https://img.shields.io/pypi/djversions/picomet)
[![PyPI - Version](https://img.shields.io/pypi/v/picomet)](https://pypi.org/project/picomet)
![PyPI - Downloads](https://img.shields.io/pypi/dw/picomet)
![GitHub](https://img.shields.io/github/license/picomet/picomet)
[![Discord](https://img.shields.io/badge/Discord-5865f2.svg?logo=discord&logoColor=white)](https://discord.gg/4byApQZg8X)

> **Tip**: Picomet isn't stable at this moment. Stability is expected with the 1.0.0 release. Remember to run `pip install --upgrade picomet` from time to time, to get the latest features and bug fixes.

## Introduction

Picomet allows you to build Single Page Applications (SPAs) with Server-Side Rendering (SSR) capabilities, seamlessly integrated with Django. What sets this framework apart is its ability to update any specific part of a page by partially rending it on the server and to render Alpinejs syntax on the server.

## Features

-   🏚️ Single page app
-   🔎 Partial rendering
-   🏯 Nested layout
-   ☎️ Server action
-   ⚡ Hot module reload
-   🌲 Alpinejs support
-   🖌️ Tailwind support
-   ✨ Copier starter

![Picomet](example.png)

## Getting Started

Go to https://picomet.readthedocs.io for getting started

## Contribution Guideline

We welcome contributions from the community to enhance and improve the framework. If you'd like to contribute, please read [CONTRIBUTING.md](CONTRIBUTING.md).

## License

Picomet is licensed under the **MIT License**. Feel free to use it in your projects and make it even better!

## Support

If you have any questions, issues, or feature requests, please open an issue or create a discussion on GitHub. We appreciate your feedback!

Happy coding! 🚀
